part of '../boxw.dart';

abstract class BoxWShape {}

class BoxWRect extends StatelessWidget implements BoxWShape {
  const BoxWRect({
    super.key,
    required this.child,
    this.borderWidth = 1,
    this.borderColor,
    this.backgroundColor,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
    this.alignment = Alignment.centerLeft,
    this.radius,
    this.width,
    this.height,
  });

  final Widget child;
  final Color? borderColor;
  final Color? backgroundColor;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final AlignmentGeometry alignment;
  final double? radius;
  final double? width;
  final double? height;
  final double borderWidth;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: alignment,
      width: width ?? double.infinity,
      height: height,
      margin: margin,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
        border: borderColor != null || BoxWConfig.borderColor != null
            ? Border.all(
                width: borderWidth,
                color: borderColor ??
                    BoxWConfig.borderColor ??
                    Theme.of(context).colorScheme.outline,
              )
            : null,
        color: backgroundColor,
      ),
      child: Padding(
        padding: padding,
        child: child,
      ),
    );
  }
}

class BoxWCircle extends StatelessWidget implements BoxWShape {
  const BoxWCircle({
    super.key,
    required this.child,
    this.borderColor,
    this.borderWidth = 1.0,
    this.backgroundColor,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
    this.alignment = Alignment.centerLeft,
    this.width,
    this.height,
  });

  final Widget child;
  final Color? borderColor;
  final Color? backgroundColor;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final AlignmentGeometry alignment;
  final double? width;
  final double? height;
  final double borderWidth;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: alignment,
      width: width ?? double.infinity,
      height: height,
      margin: margin,
      padding: padding,
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        border: borderColor != null || BoxWConfig.borderColor != null
            ? Border.all(
                width: borderWidth,
                color: borderColor ??
                    BoxWConfig.borderColor ??
                    Theme.of(context).colorScheme.outline,
              )
            : null,
        color: backgroundColor,
      ),
      child: child,
    );
  }
}
